@@ -5,7 +5,6 @@
   (defined(x ## _FIRST) && (x ## _FIRST <= LIBCURL_VERSION_NUM) && \
    (!defined(x ## _LAST) || ( x ## _LAST >= LIBCURL_VERSION_NUM)))
 
-#define CURLALTSVC_ALTUSED_FIRST 0x074001 /* Added in 7.64.1 */
 #define CURLALTSVC_H1_FIRST 0x074001 /* Added in 7.64.1 */
 #define CURLALTSVC_H2_FIRST 0x074001 /* Added in 7.64.1 */
 #define CURLALTSVC_H3_FIRST 0x074001 /* Added in 7.64.1 */
@@ -33,6 +32,7 @@
 #define CURLE_ABORTED_BY_CALLBACK_FIRST 0x070100 /* Added in 7.1 */
 #define CURLE_AGAIN_FIRST 0x071202 /* Added in 7.18.2 */
 #define CURLE_ALREADY_COMPLETE_FIRST 0x070702 /* Added in 7.7.2 */
+#define CURLE_AUTH_ERROR_FIRST 0x074200 /* Added in 7.66.0 */
 #define CURLE_BAD_CALLING_ORDER_FIRST 0x070100 /* Added in 7.1 */
 #define CURLE_BAD_CONTENT_ENCODING_FIRST 0x070a00 /* Added in 7.10 */
 #define CURLE_BAD_DOWNLOAD_RESUME_FIRST 0x070a00 /* Added in 7.10 */
@@ -261,6 +261,7 @@
 #define CURLINFO_REDIRECT_URL_FIRST 0x071202 /* Added in 7.18.2 */
 #define CURLINFO_REQUEST_SIZE_FIRST 0x070401 /* Added in 7.4.1 */
 #define CURLINFO_RESPONSE_CODE_FIRST 0x070a08 /* Added in 7.10.8 */
+#define CURLINFO_RETRY_AFTER_FIRST 0x074200 /* Added in 7.66.0 */
 #define CURLINFO_RTSP_CLIENT_CSEQ_FIRST 0x071400 /* Added in 7.20.0 */
 #define CURLINFO_RTSP_CSEQ_RECV_FIRST 0x071400 /* Added in 7.20.0 */
 #define CURLINFO_RTSP_SERVER_CSEQ_FIRST 0x071400 /* Added in 7.20.0 */
@@ -557,6 +558,7 @@
 #define CURLOPT_RTSP_SESSION_ID_FIRST 0x071400 /* Added in 7.20.0 */
 #define CURLOPT_RTSP_STREAM_URI_FIRST 0x071400 /* Added in 7.20.0 */
 #define CURLOPT_RTSP_TRANSPORT_FIRST 0x071400 /* Added in 7.20.0 */
+#define CURLOPT_SASL_AUTHZID_FIRST 0x074200 /* Added in 7.66.0 */
 #define CURLOPT_SASL_IR_FIRST 0x071f00 /* Added in 7.31.0 */
 #define CURLOPT_SEEKDATA_FIRST 0x071200 /* Added in 7.18.0 */
 #define CURLOPT_SEEKFUNCTION_FIRST 0x071200 /* Added in 7.18.0 */
@@ -798,6 +800,7 @@
 #define CURLVERSION_NOW_FIRST 0x070a00 /* Added in 7.10 */
 #define CURLVERSION_SECOND_FIRST 0x070b01 /* Added in 7.11.1 */
 #define CURLVERSION_THIRD_FIRST 0x070c00 /* Added in 7.12.0 */
+#define CURLVERSION_SIXTH_FIRST 0x074200 /* Added in 7.66.0 */
 #define CURL_CHUNK_BGN_FUNC_FAIL_FIRST 0x071500 /* Added in 7.21.0 */
 #define CURL_CHUNK_BGN_FUNC_OK_FIRST 0x071500 /* Added in 7.21.0 */
 #define CURL_CHUNK_BGN_FUNC_SKIP_FIRST 0x071500 /* Added in 7.21.0 */
@@ -844,6 +847,7 @@
 #define CURL_HTTP_VERSION_2TLS_FIRST 0x072f00 /* Added in 7.47.0 */
 #define CURL_HTTP_VERSION_2_0_FIRST 0x072100 /* Added in 7.33.0 */
 #define CURL_HTTP_VERSION_2_PRIOR_KNOWLEDGE_FIRST 0x073100 /* Added in 7.49.0 */
+#define CURL_HTTP_VERSION_3_FIRST 0x074200 /* Added in 7.66.0 */
 #define CURL_HTTP_VERSION_NONE_FIRST 0x070901 /* Added in 7.9.1 */
 #define CURL_IPRESOLVE_V4_FIRST 0x070a08 /* Added in 7.10.8 */
 #define CURL_IPRESOLVE_V6_FIRST 0x070a08 /* Added in 7.10.8 */
@@ -945,6 +949,7 @@
 #define CURL_VERSION_GSSAPI_FIRST 0x072600 /* Added in 7.38.0 */
 #define CURL_VERSION_GSSNEGOTIATE_FIRST 0x070a06 /* Added in 7.10.6 */
 #define CURL_VERSION_HTTP2_FIRST 0x072100 /* Added in 7.33.0 */
+#define CURL_VERSION_HTTP3_FIRST 0x074200 /* Added in 7.66.0 */
 #define CURL_VERSION_HTTPS_PROXY_FIRST 0x073400 /* Added in 7.52.0 */
 #define CURL_VERSION_IDN_FIRST 0x070c00 /* Added in 7.12.0 */
 #define CURL_VERSION_IPV6_FIRST 0x070a00 /* Added in 7.10 */
